@@ -1,18 +1,15 @@
 package Memory::Process;
 
-# Pragmas.
 use base qw(Memory::Usage);
 use strict;
 use warnings;
 
-# Modules.
 use Readonly;
 
 # Constants.
 Readonly::Scalar our $EMPTY_STR => q{};
 
-# Version.
-our $VERSION = 0.04;
+our $VERSION = 0.05;
 
 # Record.
 sub record {
@@ -73,49 +70,69 @@ __END__
 =head1 SYNOPSIS
 
  use Memory::Process;
+
  my $m = Memory::Process->new(%params);
  $m->dump;
  $m->record($message, $pid);
- $m->reset;
  my @report = $m->report;
  my $report = $m->report;
+ $m->reset;
  $m->state;
 
 =head1 METHODS
 
-=over 8
+=head2 C<new>
 
-=item C<new(%params)>
+ my $m = Memory::Process->new(%params);
 
- Constructor.
+Constructor.
 
-=item C<dump()>
+Returns instance of object.
 
- Print report to STDERR.
- Returns return value of print().
+=head2 C<dump>
 
-=item C<record([$message, $pid])>
+ $m->dump;
 
- Set record.
- If message not set, use ''.
- Returns undef.
+Print report to STDERR.
 
-=item C<report()>
+Returns return value of print().
 
- Get report.
- In scalar context returns string with report.
- In array context returns array of report lines.
- First line is title.
+=head2 C<record>
 
-=item C<reset()>
+ $m->record($message, $pid);
 
- Reset records.
- Returns undef.
+Set record.
+If message not set, use ''.
 
-=item C<state()>
+Returns undef.
+
+=head2 C<report>
+
+ my @report = $m->report;
+ my $report = $m->report;
+
+Get report.
+
+In scalar context returns string with report.
+In array context returns array of report lines.
+First line is title.
+
+=head2 C<reset>
+
+ $m->reset;
+
+Reset records.
+
+Returns undef.
+
+=head2 C<state>
+
+ $m->state;
+
+Get internal state.
+
+Each state item consists from:
 
- Get internal state.
- Each state item consists from:
  - timestamp (in seconds since epoch)
  - message (from record())
  - virtual memory size (in kB)
@@ -123,17 +140,16 @@ __END__
  - shared memory size (in kB)
  - text size (in kB)
  - data and stack size (in kB)
- Returns reference to array with state items.
 
-=back
+Returns reference to array with state items.
 
 =head1 EXAMPLE1
 
- # Pragmas.
+=for comment filename=run_process_and_get_report.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Memory::Process;
 
  # Object.
@@ -157,11 +173,11 @@ __END__
 
 =head1 EXAMPLE2
 
- # Pragmas.
+=for comment filename=run_process_and_get_state.pl
+
  use strict;
  use warnings;
 
- # Modules.
  use Data::Printer;
  use Memory::Process;
 
@@ -234,21 +250,22 @@ Tools to determine actual memory usage
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Memory-Process>
+L<https://github.com/michal-josef-spacek/Memory-Process>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz/>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2014-2015 Michal Špaček
- BSD 2-Clause License
+© 2014-2023 Michal Josef Špaček
+
+BSD 2-Clause License
 
 =head1 VERSION
 
-0.04
+0.05
 
 =cut
